[![Documentation Status](https://readthedocs.org/projects/py-processors/badge/?version=latest)](http://py-processors.readthedocs.io/en/latest/?badge=latest) [![Pypi version](https://img.shields.io/pypi/v/py-processors.svg)](https://pypi.python.org/pypi/py-processors)  [![Build Status](https://travis-ci.org/myedibleenso/py-processors.svg?branch=master)](https://travis-ci.org/myedibleenso/py-processors) [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/myedibleenso/py-processors/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/myedibleenso/py-processors/?branch=master) [![Coverage Status](https://coveralls.io/repos/github/myedibleenso/py-processors/badge.svg?branch=master)](https://coveralls.io/github/myedibleenso/py-processors?branch=master) [![Requirements Status](https://requires.io/github/myedibleenso/py-processors/requirements.svg?branch=master)](https://requires.io/github/myedibleenso/py-processors/requirements/?branch=master)

# Overview

See [README](docs/index.md)

# Documentation
[Documentation is here](http://py-processors.readthedocs.io/en/latest/)
